# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.flaskDebug

Module implementing checks for running a flask application with enabled debug.

### Global Attributes

None

### Classes

None

### Functions

checkFlaskDebug | Function to check for a flask app being run with debug.
getChecks | Public method to get a dictionary with checks handled by this module.

## checkFlaskDebug

checkFlaskDebug(reportError, context, _config)

Function to check for a flask app being run with debug.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up